#
# spec file for package perl-UUID
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name UUID
Name:           perl-UUID
Version:        0.370.0
Release:        1.2
# 0.37 -> normalize -> 0.370.0
%define cpan_version 0.37
License:        Artistic-2.0
Summary:        Universally Unique Identifier library for Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JR/JRM/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta)
BuildRequires:  perl(Devel::CheckLib) >= 1.14
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.06
BuildRequires:  perl(List::Util) >= 1.29
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(version) >= 0.77
Provides:       perl(UUID) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  libuuid-devel
# MANUAL END

%description
The UUID library is used to generate unique identifiers for objects that
may be accessible beyond the local system. For instance, they could be used
to generate unique HTTP cookies across multiple web servers without
communication between the servers, and without fear of a name clash.

The generated UUIDs can be reasonably expected to be unique within a
system, and unique across all systems, and are compatible with those
created by the Open Software Foundation (OSF) Distributed Computing
Environment (DCE).

All generated UUIDs are either version 1, 3, 4, 5, 6, or version 7. And all
are variant 1, meaning compliant with the OSF DCE standard as described in
RFC4122.

Versions 6 and 7 are not standardized. They are presented here as proposed
in RFC4122bis, version 14, and may change in the future. RFC4122bis is
noted to replace RFC4122, if approved.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes NOTES README
%license LICENSE

%changelog
* Tue Feb 25 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.370.0 (0.37)
  see /usr/share/doc/packages/perl-UUID/Changes
  0.37 Mon Feb 24 04:25:27 EST 2025
  - Fix build under gcc-15 default ISO C23.
  - Thanks Petr Pisar. [rt.cpan.org #159112]
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 0.360.0 (0.36)
  see /usr/share/doc/packages/perl-UUID/Changes
  0.36 Sat Jun 22 21:24:39 EDT 2024
  - Fix distro tests run from read-only location.
  - Thanks Petr Pisar. [rt.cpan.org #153854]
  0.35 Wed May 29 14:40:34 EDT 2024
  - Reworked persist file handling for speed.
  - Reworked seeding for front-loading prefork processes.
  - Thanks again to Christopher Rasch-Olsen Raa.
* Tue Apr 30 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.34
  see /usr/share/doc/packages/perl-UUID/Changes
* Fri Mar 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-UUID/Changes
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Dec 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.32
  see /usr/share/doc/packages/perl-UUID/Changes
* Wed Nov  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.31
  see /usr/share/doc/packages/perl-UUID/Changes
  ToDo:
  - Bump dev version.
  - Bump release version and fixup Changes.
  0.31 Mon Nov  6 23:43:58 EST 2023
  - Strip leading whitespace from assertlib files.
  - Use not_execute during configure.
  - Remove double quote area in Makefile.PL.
  - Remove placeholder files in repo.
  - Manifest tidy.
  - Add tests for generated files.
  - Remove old README_new file first. Make generation required.
  - Generate license file and test.
  - Skip 0gen test except in disttest. (UUID_DISTTEST=1)
  - Make 0gen tests fail for empty files.
  - OCD manifest tweak.
  - Add comments to Makefile modifications.
  - Silence manicopy call in configure.
  - Make generated metafiles authoritative.
  - Thanks to twata. [rt.cpan.org #150311]
  - Test metafiles for authority.
  - Bump dev version.
  - Add DynaLoader and Exporter to PREREQ_PM.
  - Add comments for other prereqs.
  - Move VERSION closer to top.
  - Remove NO_MYMETA if EUMM < 6.58.
  - Re-enable warnings.
  - Remove forced debug.
  - Bump dev version.
  - Rename License to LICENSE, per Kwalitee.
  - Add check for copyright year in disttest.
  - Add 'provides' info to metafiles, per Kwalitee.
  - Move dynamic_config to WriteMakefile().
  - Tweak copyright test.
  - Bump dev version.
  - Make sure generated files are in manifest.
  - Fix wayward LICENSE.
  - Add test deps, per Kwalitee.
  - Bump dev version.
  - Check copyright date in LICENSE.
  - Bump release version.
  0.30 Tue Oct 31 17:16:50 EDT 2023
  - Make all devel version use UUID_DEBUG=1.
  - Bump ExtUtils::MakeMaker prereq to 6.64 (first version supporting
    TEST_REQUIRES).
  - Add debug message to show current Devel::CheckLib::VERSION.
  - Add debug message to show current ExtUtils::MakeMaker::VERSION.
  - Reorder configure tests for win32.
  - Add RPC_CSTR typedef for older Win32.
  - Define UuidCreateSequential() for older Win32.
  - Make META.json and META.yml placeholders. Generate during distdir.
  - Make README a placeholder. Generate during distdir.
  - Fix trivial build warning.
  0.29 Wed Oct 25 01:15:57 EDT 2023
  - Bump prereq version for Devel::CheckLib to 1.14 to fix problems with
    Strawberry versions 5.18 to 5.28. Earlier Strawberry did not ship
    Devel::CheckLib. Newer versions shipped 1.14 or later.
  - Thanks to twata. [rt.cpan.org #143841]
* Tue Sep  3 2019 Tina Mueller <tina.mueller@suse.com>
- Add BuildRequires:  libuuid-devel
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.28
  see /usr/share/doc/packages/perl-UUID/Changes
  0.28 Sat Dec 29 00:59:25 EST 2018
  - Add OSSP variant of libuuid. CentOS7 (and presumably other RedHat
    derivatives) have packages for both OSSP and e2fs. Favor e2fs, if
    found, since our implementation of OSSP is probably slower.
  - Thanks to Greg Cox. [rt.cpan.org #128122]
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-UUID/Changes
  0.27 Fri Sep 23 01:52:00 EDT 2016
  - Update SYNOPSIS to remove ":all". Indiscriminate exports could cause
    problems with other modules, such as File::Copy::copy().
  - Thanks to Slaven Rezic. [rt.cpan.org #118033]
  0.26 Sat May  7 02:32:52 EDT 2016
  - Fix broken @ARGV handling in Makefile.PL regarding debug flag.
  - Also changed DEBUG flag to UUID_DEBUG
  - Thanks to gregor herrmann. [rt.cpan.org #114213]
  0.25 Mon Mar 14 10:15:55 EDT 2016
  - Changed all prints in Makefile.PL to warns and made both
    unbuffered to match Devel::CheckLib
  - Remove uuid_unparse_lower/upper() calls which don't exist
    on SunOS
  - Ignore TEST_REQUIRES on EUMM < 6.64
  - Try to find correct link lib (-lrpcrt4, -luuid, -lc, in order)
  - Make string argument a char** for uuid_to_string()
  - Add note on Linux UUID packages
  - Moved test.pl to t/test.t and updated to Test::More
  - Changed debug() to emit to stderr to match Devel::CheckLib
  - Removed Makefile.PL verbosity
  - Added switch to Makefile.PL to incite verbosity
  - Become verbose for smokers only on dev releases
  - Added build notice for missing header/libraries
  - Bail out of build if uuid_t size == 0
  - Reorganized header/library search to find wayward OSX
  - Thanks to David Wheeler and William Faulk for pointers and
    lots of patience in testing. [rt.cpan.org #104394]
  0.24 Mon Jan 19 01:05:14 EST 2015
  - Add 'extern "C"' for g++
  0.23 Sun Dec 28 18:58:04 EST 2014
  - Reverse order of rpc.h and rpcdce.h in UUID.xs (rpc.h first)
  0.22 Sun Dec 28 08:42:23 EST 2014
  - Ugh! Forgot to include rpcdce.h in UUID.xs
  0.21 Sun Dec 28 08:35:23 EST 2014
  - Instead of unistd.h, try rpcdce.h on Win
  - Minor cleanup in test.pl
  0.20 Sat Dec 27 19:27:28 EST 2014
  - Also include unistd.h when using Rpc.h (Win)
  - Fix pointer problem in -luuid search on Win
  - Fix minor header propagation problem in Makefile.PL
  0.19 Fri Dec 26 17:09:12 EST 2014
  - Fix pointer confusion in do_uuid() on BSD [rt.cpan.org #101137]
  0.18 Fri Dec 26 08:20:06 EST 2014
  - Allow for non-true/false return from uuid_from_string() on BSD
  - Remove unused dependency on Config.pm
  - Added yet more debug info for 'make test' time
  - Change -DPERL__UUID__UUID_BUF_SZ to -DPERL__UUID__STRUCT_SZ
  0.17 Fri Dec 26 05:05:13 EST 2014
  - Removed two nested comments on BSD /* sigh */
  - Let e2fs machines use sv_cmp too (let's see if OSX Frankenbox works)
  - Changed warns in Makefile.PL to prints
  0.16 Thu Dec 25 18:24:23 EST 2014
  - Typo on Windows/BSD
  - Trying sv_cmp() instead of uuid_compare() on RPC-based machines
  0.15 Thu Dec 25 05:55:13 EST 2014
  - REALLY fix do_uuid() typo. Really.
  - Fix pointer problems on BSD
  - Removed uuid_copy() from BSD. How did that get there? =)
  - Added yet another test for OSX segfault!
  - Check and set -DPERL__UUID__UUID_BUF_SZ=?? in Makefile.PL
    (Should be the same everywhere, right? Right?)
  0.14 Wed Dec 24 22:39:42 EST 2014
  - Fix typo in Windows do_uuid() for compiler fail on strawberry
  - Now checking for all header files instead of taking first
  - Added more detail for failed interface search
  - Added check for uuid struct size
  0.13 Wed Dec 24 07:45:49 EST 2014
  - Split -luuid search into header file and interface type stages
  - Removed SvPV_nolen everywhere (buffer overflows)
  0.12 Wed Dec 24 03:07:50 EST 2014
  - Added support for non-e2fs systems (BSD, OSX, Win)
  0.11_01 Tue Dec 23 20:23:29 EST 2014
  - Modified test.pl to hopefully catch where MacOSX fails
  - Heavy mods to Makefile.PL to differentiate between interfaces
  - Makefile.PL *lots* more verbose
  - Lots of #ifdefs added in XS
  - First shot at code that works for BSD style interface
  0.11 Mon Dec 22 19:03:09 EST 2014
  - Looks like I've managed to cut the failure reports down a little TOO
    far, so now splitting the search for -luuid into two separate
    phases. The first, which I don't want to deal with right now, tests
    for usability of the -luuid flag by itself. The second, tests for
    usability of individual functions. We'll deal with platforms that
    actually find libuuid first, then MAYBE revisit others.
  0.10 Mon Dec 22 11:55:30 EST 2014
  - Added clear() and is_null()
  - Added copy() and compare()
  - Added unparse_lower() and unparse_upper()
  - Added generate_random() and generate_time()
  0.09 Mon Dec 22 04:31:26 EST 2014
  - Drag test.pl into this century using Test.pm
  - Add postamble to Makefile to generate README
  - Overhaul POD
  - Fix MacOS warning "unsigned char* <--> char*"
  0.08 Sun Dec 21 06:06:21 EST 2014
  - Added README with pod2text UUID.pm README
  - Switched libuuid search to Devel::CheckLib
  0.07 Sat Dec 20 21:12:17 EST 2014
  - Updated Makefile.PL
  - Added search for -luuid at Makefile.PL time
  - Updated license and POD to Artistic 2.0
  0.06 Thu Dec 18 08:01:44 EST 2014
  - Took over maintaining (Rick Myers - JRM)
  - Added uuid()
  0.05 Fri Dec 14 20:00:00 GMT 2012
  - Took over maintaining (Lukas Zapletal - LZAP)
  - Version bump (no changes)
  - Releasing in the original location
  0.04 Wed Jul 22 20:17:26 PDT 2009
  - Seems to be abandoned (again)
  - Bump version number and upload to PAUSE
  0.03  Fri Jan 12 15:24:24 MST 2007
  - Added Artistic license
  - Took over maintaining (Colin Faber - CFABER)
  0.02  Unknown
  - unknown changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.03
  see /usr/share/doc/packages/perl-UUID/Changes
  0.03  Fri Jan 12 15:24:24 MST 2007
  - Added Artistic license
  - Took over maintaining (Colin Faber - CFABER)
  0.02  Unknown
  - unknown changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Oct 15 2010 chris@computersalat.de
- initial package 0.03
  * created by cpanspec 1.78
